@@ -16,7 +16,7 @@
 #ifndef RADIUSD_H
 #define RADIUSD_H
 /**
- * $Id: 1123b777a238b6e291aec9e182c584ca65101cd7 $
+ * $Id: 028202fe2cc8eff66a5b1a126b17aeac7b496b86 $
  *
  * @file radiusd.h
  * @brief Structures, prototypes and global variables for the FreeRADIUS server.
@@ -24,7 +24,7 @@
  * @copyright 1999-2000,2002-2008  The FreeRADIUS server project
  */
 
-RCSIDH(radiusd_h, "$Id: 1123b777a238b6e291aec9e182c584ca65101cd7 $")
+RCSIDH(radiusd_h, "$Id: 028202fe2cc8eff66a5b1a126b17aeac7b496b86 $")
 
 #include <freeradius/libradius.h>
 #include <freeradius/radpaths.h>
@@ -55,7 +55,7 @@ typedef struct rad_request REQUEST;
 #endif
 
 #ifdef WITH_TLS
-#  include <freeradius-devel/tls.h>
+#  include <freeradius/tls.h>
 #endif
 
 #include <freeradius/stats.h>
@@ -114,7 +114,10 @@ typedef struct main_config {
 	fr_ipaddr_t	myip;				//!< IP to bind to. Set on command line.
 	uint16_t	port;				//!< Port to bind to. Set on command line.
 
-	bool		log_auth;			//!< Log authentication attempts.
+	bool		suppress_secrets;		//!< for debug levels < 3
+	bool		log_auth;			//!< Log all authentication attempts.
+	bool		log_accept;			//!< Log Access-Accept
+	bool		log_reject;			//!< Log Access-Reject
 	bool		log_auth_badpass;		//!< Log successful authentications.
 	bool		log_auth_goodpass;		//!< Log failed authentications.
 	char const	*auth_badpass_msg;		//!< Additional text to append to successful auth messages.
@@ -167,6 +170,8 @@ typedef struct main_config {
 
 	bool		write_pid;			//!< write the PID file
 
+	bool		exiting;			//!< are we exiting?
+
 
 #ifdef ENABLE_OPENSSL_VERSION_CHECK
 	char const	*allow_vulnerable_openssl;	//!< The CVE number of the last security issue acknowledged.
@@ -222,6 +227,8 @@ struct rad_request {
 
 	VALUE_PAIR		*config;	//!< #VALUE_PAIR (s) used to set per request parameters
 						//!< for modules and the server core at runtime.
+
+	TALLOC_CTX		*state_ctx;	//!< for request->state
 	VALUE_PAIR		*state;		//!< #VALUE_PAIR (s) available over the lifetime of the authentication
 						//!< attempt. Useful where the attempt involves a sequence of
 						//!< many request/challenge packets, like OTP, and EAP.
@@ -272,8 +279,6 @@ struct rad_request {
 #ifdef WITH_PROXY
 	bool			in_proxy_hash;
 
-	struct timeval		proxy_retransmit;
-
 	uint32_t		num_proxied_requests;	//!< How many times this request was proxied.
 							//!< Retransmissions are driven by requests from the NAS.
 	uint32_t		num_proxied_responses;
@@ -308,8 +313,9 @@ struct rad_request {
 #define RAD_REQUEST_LVL_DEBUG3	(3)
 #define RAD_REQUEST_LVL_DEBUG4	(4)
 
-#define RAD_REQUEST_OPTION_COA	(1 << 0)
-#define RAD_REQUEST_OPTION_CTX	(1 << 1)
+#define RAD_REQUEST_OPTION_COA		(1 << 0)
+#define RAD_REQUEST_OPTION_CTX 		(1 << 1)
+#define RAD_REQUEST_OPTION_CANCELLED	(1 << 2)
 
 #define SECONDS_PER_DAY		86400
 #define MAX_REQUEST_TIME	30
@@ -342,7 +348,6 @@ typedef enum request_fail {
  *
  *	We really shouldn't have this many.
  */
-extern char const	*progname;
 extern log_lvl_t	rad_debug_lvl;
 extern char const	*radacct_dir;
 extern char const	*radlog_dir;
@@ -413,6 +418,7 @@ uint32_t	rad_pps(uint32_t *past, uint32_t *present, time_t *then, struct timeval
 int		rad_expand_xlat(REQUEST *request, char const *cmd,
 				int max_argc, char const *argv[], bool can_fail,
 				size_t argv_buflen, char *argv_buf);
+void		rad_tv_sub(struct timeval const *end, struct timeval const *start, struct timeval *elapsed);
 
 void		verify_request(char const *file, int line, REQUEST *request);	/* only for special debug builds */
 void		rad_mode_to_str(char out[10], mode_t mode);
