@@ -5,11 +5,11 @@
  * realms.h	Structures, prototypes and global variables
  *		for realms
  *
- * Version:	$Id: 8208b8f04cff3dce664433486b65cccb3a3f8c14 $
+ * Version:	$Id: dcb420371e5f1927792a2ea1108097bbc109a1eb $
  *
  */
 
-RCSIDH(realms_h, "$Id: 8208b8f04cff3dce664433486b65cccb3a3f8c14 $")
+RCSIDH(realms_h, "$Id: dcb420371e5f1927792a2ea1108097bbc109a1eb $")
 
 #ifdef __cplusplus
 extern "C" {
@@ -36,10 +36,11 @@ typedef enum {
 } home_ping_check_t;
 
 typedef enum {
-	HOME_STATE_ALIVE = 0,
+	HOME_STATE_UNKNOWN = 0,
+	HOME_STATE_ALIVE,
 	HOME_STATE_ZOMBIE,
 	HOME_STATE_IS_DEAD,
-	HOME_STATE_UNKNOWN
+	HOME_STATE_CONNECTION_FAIL,
 } home_state_t;
 
 typedef struct fr_socket_limit_t {
@@ -58,6 +59,7 @@ typedef struct home_server {
 							//!< stats or when specifying home servers for a pool.
 
 	bool			dual;			//!< One of a pair of homeservers on consecutive ports.
+	bool			dynamic;		//!< is this a dynamically added home server?
 	char const		*server;		//!< For internal proxying
 	char const		*parent_server;
 
@@ -159,6 +161,7 @@ typedef struct home_pool_t {
 	home_server_t		*fallback;
 	int			in_fallback;
 	time_t			time_all_dead;
+	time_t			last_serviced;
 
 	int			num_home_servers;
 	home_server_t		*servers[1];
@@ -193,6 +196,7 @@ int		realm_realm_add( REALM *r, CONF_SECTION *cs);
 void		home_server_update_request(home_server_t *home, REQUEST *request);
 home_server_t	*home_server_ldb(char const *realmname, home_pool_t *pool, REQUEST *request);
 home_server_t	*home_server_find(fr_ipaddr_t *ipaddr, uint16_t port, int proto);
+home_server_t	*home_server_find_bysrc(fr_ipaddr_t *ipaddr, uint16_t port, int proto, fr_ipaddr_t *src_ipaddr);
 home_server_t	*home_server_afrom_cs(TALLOC_CTX *ctx, realm_config_t *rc, CONF_SECTION *cs);
 CONF_SECTION	*home_server_cs_afrom_client(CONF_SECTION *client);
 #ifdef WITH_COA
@@ -203,6 +207,9 @@ home_server_t	*home_server_bynumber(int number);
 #endif
 home_pool_t	*home_pool_byname(char const *name, int type);
 
+int		home_server_afrom_file(char const *filename);
+int		home_server_delete(char const *name, char const *type);
+
 #ifdef __cplusplus
 }
 #endif
